==> WinBinder-0.32.108.tgz: Source/wb/wb_generic.c <==
/*******************************************************************************

 WINBINDER - A native Windows binding

 Copyright  2004 Hypervisual - see LICENSE.TXT for details
 Author: Rubem Pechansky (pechansky@hypervisual.com)

 General-purpose functions

*******************************************************************************/

//----------------------------------------------------------------- DEPENDENCIES

#include "wb.h"

//----------------------------------------------------------- EXPORTED FUNCTIONS

BOOL wbGetTextSize(PSIZE psizText, LPCTSTR pszString)
{
	int nLen;
	HDC cvTest;

	if(!psizText)
		return FALSE;
	nLen = strlen(pszString);

	cvTest = CreateCompatibleDC(NULL);
	GetTextExtentPoint32(cvTest, (LPTSTR)pszString, nLen, psizText);
	DeleteDC(cvTest);
	return TRUE;
}

BOOL wbIsWBObj(void *pwbo)
{
	if(!pwbo) {
		wbError(MB_ICONWARNING, "%s: NULL WinBinder object", __func__);
		return FALSE;
	}

	// A Windows or menu handle is not a WinBinder Object

	if(IsWindow(pwbo) || IsMenu(pwbo)) {
		wbError(MB_ICONWARNING, "%s: Windows handle is not a WinBinder object", __func__);
		return FALSE;
	}

	// Does it have a valid handle?

	if(!((PWBOBJ)pwbo)->handle) {
		wbError(MB_ICONWARNING, "%s: NULL WinBinder object handle", __func__);
		return FALSE;
	}

	if(IsMenu(((PWBOBJ)pwbo)->handle))
		return TRUE;

	if(IsWindow(((PWBOBJ)pwbo)->handle))
		return TRUE;

	wbError(MB_ICONWARNING, "%s: Invalid WinBinder object", __func__);
	return FALSE;
}

/* TODO: Return PWBOBJ from menus too */

PWBOBJ wbGetWBObj(HANDLE hwnd)
{
	if(IsWindow(hwnd)) {
		return (PWBOBJ)GetWindowLong((HWND)hwnd, GWL_USERDATA);

/*
		} else if(IsMenu(hwnd)) {
		MENUITEMINFO mi;

		GetMenuItemInfo((HMENU)hwnd, 0, TRUE, &mi);
		if(!((PWBOBJ)(mi.dwItemData)))
			printf("MENU: NULL\n");
		else
			printf("MENU: %d\n", ((PWBOBJ)(mi.dwItemData))->parent);
		return (PWBOBJ)(mi.dwItemData);*/

	} else
		return NULL;
}

//------------------------------------------------------------------ END OF FILE

==> WinBinder-0.33.113.tgz: Source/wb/wb_generic.c <==
/*******************************************************************************

 WINBINDER - A native Windows binding

 Copyright  2004 Hypervisual - see LICENSE.TXT for details
 Author: Rubem Pechansky (pechansky@hypervisual.com)

 General-purpose functions

*******************************************************************************/

//----------------------------------------------------------------- DEPENDENCIES

#include "wb.h"

//----------------------------------------------------------- EXPORTED FUNCTIONS

BOOL wbGetTextSize(PSIZE psizText, LPCTSTR pszString)
{
	int nLen;
	HDC cvTest;

	if(!psizText)
		return FALSE;
	nLen = strlen(pszString);

	cvTest = CreateCompatibleDC(NULL);
	GetTextExtentPoint32(cvTest, (LPTSTR)pszString, nLen, psizText);
	DeleteDC(cvTest);
	return TRUE;
}

BOOL wbIsWBObj(void *pwbo, BOOL bShowErrors)
{
	if(!pwbo) {
		if(bShowErrors)
			wbError(__func__, MB_ICONWARNING, "NULL WinBinder object");
		return FALSE;
	}

	// Is pwbo a valid memory address?

	if(IsBadReadPtr(pwbo, sizeof(WBOBJ))) {
		if(bShowErrors)
			wbError(__func__, MB_ICONWARNING, "Invalid memory address");
		return FALSE;
	}

	// A Windows or menu handle is not a WinBinder object

	if(IsWindow(pwbo) || IsMenu(pwbo)) {
		if(bShowErrors)
			wbError(__func__, MB_ICONWARNING, "Not a WinBinder object");
		return FALSE;
	}

	// Does it have a valid handle?

	{
		PWBOBJ pwboTest = wbMalloc(sizeof(WBOBJ));

		CopyMemory(pwboTest, pwbo, sizeof(WBOBJ));

		if(!pwboTest->handle) {
			if(bShowErrors)
				wbError(__func__, MB_ICONWARNING, "NULL WinBinder object handle");
			return FALSE;
		}
	}

	if(IsMenu((HMENU)((PWBOBJ)pwbo)->handle))
		return TRUE;

	if(IsWindow((HWND)((PWBOBJ)pwbo)->handle))
		return TRUE;

	if(bShowErrors)
		wbError(__func__, MB_ICONWARNING, "Invalid WinBinder object");

	return FALSE;
}

/* TODO: Return PWBOBJ from menus too */

PWBOBJ wbGetWBObj(HANDLE hwnd)
{
	if(IsWindow(hwnd)) {
		return (PWBOBJ)GetWindowLong((HWND)hwnd, GWL_USERDATA);

/*
	} else if(IsMenu(hwnd)) {

		MENUITEMINFO mi;

		GetMenuItemInfo((HMENU)hwnd, 0, TRUE, &mi);
		if(!((PWBOBJ)(mi.dwItemData)))
			printf("MENU: NULL\n");
		else
			printf("MENU: %d\n", ((PWBOBJ)(mi.dwItemData))->parent);
		return (PWBOBJ)(mi.dwItemData);*/

	} else
		return NULL;
}

//------------------------------------------------------------------ END OF FILE
